==> libssh-docs-0.11.1-1-x86_64.pkg.tar.zst: usr/share/doc/libssh/html/search/all_18.js <==
var searchData=
[
  ['o_0',['O',['../libssh_tutor_sftp_aio.html',1,'Chapter 10: The SFTP asynchronous I/O'],['../libssh_tutor_sftp_aio.html#sftp_aio_api',1,'The SFTP asynchronous I/O']]],
  ['of_20a_20directory_1',['Listing the contents of a directory',['../libssh_tutor_sftp.html#sftp_ls',1,'']]],
  ['of_20sftp_5faio_5ffree_2',['Example showing the usage of sftp_aio_free()',['../libssh_tutor_sftp_aio.html#sftp_aio_free',1,'']]],
  ['of_20supported_20authentications_3',['Getting the list of supported authentications',['../libssh_tutor_authentication.html#auth_list',1,'']]],
  ['of_20threads_4',['Initialization of threads',['../libssh_tutor_threads.html#threads_init',1,'']]],
  ['on_20a_20file_20on_20the_20remote_20computer_5',['Performing an asynchronous read/write on a file on the remote computer',['../libssh_tutor_sftp.html#sftp_aio',1,'']]],
  ['on_20authentication_6',['on authentication',['../libssh_tutor_authentication.html#authentication_details',1,'A deeper insight on authentication'],['../libssh_tutor_authentication.html',1,'Chapter 2: A deeper insight on authentication']]],
  ['on_20the_20remote_20computer_7',['on the remote computer',['../libssh_tutor_sftp.html#sftp_aio',1,'Performing an asynchronous read/write on a file on the remote computer'],['../libssh_tutor_sftp.html#sftp_write',1,'Writing to a file on the remote computer']]],
  ['on_20the_20remote_20side_8',['Using graphical applications on the remote side',['../libssh_tutor_shell.html#x11',1,'']]],
  ['opening_20a_20remote_20shell_9',['Opening a remote shell',['../libssh_tutor_shell.html',1,'Chapter 3: Opening a remote shell'],['../libssh_tutor_shell.html#opening_shell',1,'Opening a remote shell']]],
  ['opening_20and_20closing_20a_20channel_10',['Opening and closing a channel',['../libssh_tutor_shell.html#open_channel',1,'']]],
  ['opening_20and_20closing_20a_20scp_20session_11',['Opening and closing a SCP session',['../libssh_tutor_scp.html#scp_session',1,'']]],
  ['opening_20and_20closing_20a_20sftp_20session_12',['Opening and closing a SFTP session',['../libssh_tutor_sftp.html#sftp_session',1,'']]],
  ['openssl_203_200_208_13',['Pre-requisites (OpenSSL 3.0.8+)',['../libssh_tutor_pkcs11.html#autotoc_md2',1,'']]],
  ['openssl_203_200_20_3a_14',['Pre-requisites (OpenSSL &lt; 3.0):',['../libssh_tutor_pkcs11.html#autotoc_md1',1,'']]],
  ['options_15',['Creating the session and setting options',['../libssh_tutor_guided_tour.html#setup',1,'']]],
  ['optionscopy_16',['optionsCopy',['../classssh_1_1Session.html#ac95e750dc93d77fe463cbd054a87934a',1,'ssh::Session']]],
  ['optionsparseconfig_17',['optionsParseConfig',['../classssh_1_1Session.html#af19a7b347ddc520d027d94c4d8073aaa',1,'ssh::Session']]]
];

==> libssh-docs-0.11.2-1.1-x86_64.pkg.tar.zst: usr/share/doc/libssh/html/search/all_18.js <==
var searchData=
[
  ['o_0',['O',['../libssh_tutor_sftp_aio.html',1,'Chapter 10: The SFTP asynchronous I/O'],['../libssh_tutor_sftp_aio.html#sftp_aio_api',1,'The SFTP asynchronous I/O']]],
  ['of_20a_20directory_1',['Listing the contents of a directory',['../libssh_tutor_sftp.html#sftp_ls',1,'']]],
  ['of_20sftp_5faio_5ffree_2',['Example showing the usage of sftp_aio_free()',['../libssh_tutor_sftp_aio.html#sftp_aio_free',1,'']]],
  ['of_20supported_20authentications_3',['Getting the list of supported authentications',['../libssh_tutor_authentication.html#auth_list',1,'']]],
  ['of_20threads_4',['Initialization of threads',['../libssh_tutor_threads.html#threads_init',1,'']]],
  ['on_20a_20file_20on_20the_20remote_20computer_5',['Performing an asynchronous read/write on a file on the remote computer',['../libssh_tutor_sftp.html#sftp_aio',1,'']]],
  ['on_20authentication_6',['on authentication',['../libssh_tutor_authentication.html#authentication_details',1,'A deeper insight on authentication'],['../libssh_tutor_authentication.html',1,'Chapter 2: A deeper insight on authentication']]],
  ['on_20the_20remote_20computer_7',['on the remote computer',['../libssh_tutor_sftp.html#sftp_aio',1,'Performing an asynchronous read/write on a file on the remote computer'],['../libssh_tutor_sftp.html#sftp_write',1,'Writing to a file on the remote computer']]],
  ['on_20the_20remote_20side_8',['Using graphical applications on the remote side',['../libssh_tutor_shell.html#x11',1,'']]],
  ['opening_20a_20remote_20shell_9',['Opening a remote shell',['../libssh_tutor_shell.html',1,'Chapter 3: Opening a remote shell'],['../libssh_tutor_shell.html#opening_shell',1,'Opening a remote shell']]],
  ['opening_20and_20closing_20a_20channel_10',['Opening and closing a channel',['../libssh_tutor_shell.html#open_channel',1,'']]],
  ['opening_20and_20closing_20a_20scp_20session_11',['Opening and closing a SCP session',['../libssh_tutor_scp.html#scp_session',1,'']]],
  ['opening_20and_20closing_20a_20sftp_20session_12',['Opening and closing a SFTP session',['../libssh_tutor_sftp.html#sftp_session',1,'']]],
  ['openssl_203_200_208_13',['Pre-requisites (OpenSSL 3.0.8+)',['../libssh_tutor_pkcs11.html#autotoc_md2',1,'']]],
  ['openssl_203_200_20_3a_14',['Pre-requisites (OpenSSL &amp;lt; 3.0):',['../libssh_tutor_pkcs11.html#autotoc_md1',1,'']]],
  ['options_15',['Creating the session and setting options',['../libssh_tutor_guided_tour.html#setup',1,'']]],
  ['optionscopy_16',['optionsCopy',['../classssh_1_1Session.html#ac95e750dc93d77fe463cbd054a87934a',1,'ssh::Session']]],
  ['optionsparseconfig_17',['optionsParseConfig',['../classssh_1_1Session.html#af19a7b347ddc520d027d94c4d8073aaa',1,'ssh::Session']]]
];
